.. _index:

Nanite is a Python library for loading, fitting, and
rating AFM force-distance data of cells and tissues.
This is the documentation of nanite version |release|.


Documentation
=============

.. toctree::
   :maxdepth: 3

   sec_getting_started
   sec_cli
   sec_fitting_guide
   sec_rating_workflow
   sec_examples
   sec_develop
   sec_code_reference

.. toctree::
   :maxdepth: 1

   sec_changelog
   sec_z_bib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
